@@ -11,7 +11,11 @@ from .validators import is_valid_isbn, is_valid_url, sanitize_isbn
 
 
 class QuerySchema(BaseModel):
-    pass
+    gid: str
+
+    @property
+    def id(self) -> int:
+        return int(self.gid.split("/")[-1])
 
 
 class MutationSchema(BaseModel, abc.ABC):
@@ -21,17 +25,11 @@ class MutationSchema(BaseModel, abc.ABC):
 
 
 class ShopifyShop(QuerySchema):
-    gid: str
     name: str
     myshopify_domain: str
 
-    @property
-    def id(self) -> int:
-        return int(self.gid.split("/")[-1])
-
 
 class ShopifyBook(QuerySchema):
-    gid: str
     isbn: str
     title: str
     author: t.Optional[str]
@@ -41,10 +39,6 @@ class ShopifyBook(QuerySchema):
     publisher: t.Optional[str]
     published_date: t.Optional[str]
 
-    @property
-    def id(self) -> int:
-        return int(self.gid.split("/")[-1])
-
 
 class CreateBookInput(MutationSchema):
     isbn: str
@@ -208,3 +202,7 @@ class CreateMetafieldDefinitionInput(MutationSchema):
             "ownerType": self.owner_type,
             "namespace": self.namespace,
         }
+
+
+class Publication(QuerySchema):
+    name: str
